@@ -1,6 +1,6 @@
 use rsix::io::{self, isatty, stderr, stdin, stdout, ttyname};
-use std::ffi::OsString;
 use rsix::io_lifetimes::AsFd;
+use std::ffi::OsString;
 
 fn main() -> io::Result<()> {
     let (stdin, stdout, stderr) = unsafe { (stdin(), stdout(), stderr()) };
@@ -23,18 +23,9 @@ fn show<Fd: AsFd>(fd: &Fd) -> io::Result<()> {
             " - ttyname: {}",
             ttyname(fd, OsString::new())?.to_string_lossy()
         );
-        println!(
-            " - attrs: {:?}",
-            rsix::io::ioctl_tcgets(fd)?
-        );
-        println!(
-            " - winsize: {:?}",
-            rsix::io::ioctl_tiocgwinsz(fd)?
-        );
-        println!(
-            " - ready: {:?}",
-            rsix::io::ioctl_fionread(fd)?
-        );
+        println!(" - attrs: {:?}", rsix::io::ioctl_tcgets(fd)?);
+        println!(" - winsize: {:?}", rsix::io::ioctl_tiocgwinsz(fd)?);
+        println!(" - ready: {:?}", rsix::io::ioctl_fionread(fd)?);
     } else {
         println!("Stderr is not a tty");
     }
