@@ -3,12 +3,12 @@ use crate::io::{self, OwnedFd};
 use crate::net::{SocketAddr, SocketAddrUnix, SocketAddrV4, SocketAddrV6};
 use io_lifetimes::AsFd;
 
-pub use imp::net::{AcceptFlags, AddressFamily, Protocol, Shutdown, SocketType};
+pub use imp::net::{AcceptFlags, AddressFamily, Protocol, Shutdown, SocketFlags, SocketType};
 
 impl Default for Protocol {
     #[inline]
     fn default() -> Self {
-        Self::Ip
+        Self::IP
     }
 }
 
@@ -29,6 +29,31 @@ pub fn socket(domain: AddressFamily, type_: SocketType, protocol: Protocol) -> i
     imp::syscalls::socket(domain, type_, protocol)
 }
 
+/// `socket_with(domain, type_ | flags, protocol)`—Creates a socket, with
+/// flags.
+///
+/// POSIX guarantees that `socket` will use the lowest unused file descriptor,
+/// however it is not safe in general to rely on this, as file descriptors
+/// may be unexpectedly allocated on other threads or in libraries.
+///
+/// `socket_with` is the same as `socket` but adds an additional flags operand.
+///
+/// # References
+///  - [POSIX]
+///  - [Linux]
+///
+/// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/socket.html
+/// [Linux]: https://man7.org/linux/man-pages/man2/socket.2.html
+#[inline]
+pub fn socket_with(
+    domain: AddressFamily,
+    type_: SocketType,
+    flags: SocketFlags,
+    protocol: Protocol,
+) -> io::Result<OwnedFd> {
+    imp::syscalls::socket_with(domain, type_, flags, protocol)
+}
+
 /// `bind(sockfd, addr, sizeof(struct sockaddr_in))`—Binds a socket to an
 /// address.
 ///
@@ -202,7 +227,7 @@ pub fn acceptfrom<Fd: AsFd>(sockfd: &Fd) -> io::Result<(OwnedFd, SocketAddr)> {
     imp::syscalls::acceptfrom(sockfd)
 }
 
-/// `accept4(fd, &addr, &len, flags)—Accepts an incoming connection and
+/// `accept4(fd, &addr, &len, flags)`—Accepts an incoming connection and
 /// returns the peer address, with flags.
 ///
 /// Use [`accept_with`] if the peer address isn't needed.
